### 环境

* node v10.15.3
* npm v6.4.1
* ant v3.18.1
* react v16.8.3
* mobx v5.9.4



### 脚手架

* [Create React App](https://github.com/facebook/create-react-app)

* 启动打包方式

  ```bash
  # 项目启动
  npm run start
  # 项目打包
  npm run build
  ```



### webpack config

* 配置文件 /config-overrides.js
* 自定义的webpack配置参考 [customize-cra](https://github.com/arackaf/customize-cra) 文档
* 暴露[Create React App](https://github.com/facebook/create-react-app) webpack配置 npm eject（强烈不推荐暴露）



### 多语言

* plugin [i18next](https://www.i18next.com/)  [react-i18next](https://react.i18next.com/)

* 使用方式
  1. src/i18n文件夹下添加语言文件，例 zh_Hans.js
  2. src/i18n/i18n.js 引入上面添加的语言文件，并注入 resource
  3. 语言切换和语言模块使用方式参考 [react-i18next](https://react.i18next.com/)



### 路由配置

* plugin [react router v4](https://reacttraining.com/react-router/web/guides/quick-start)

* 添加路由 src/router/navRouter中配置路由信息

  ```javascript
  {
          key: 'overall',
          name: '总览',
          path: '/overall',
          icon: 'home',
          hidden:true,
          permission:[], // 填入当前路由需要的权限 当不满足权限
          component: Loadable({
              loader: () => import('../page/overall/overall'),
              loading: () => <JFLoading/>
          }),
          routes:[ // menu的二级菜单  当设置二级菜单时 一级菜单的链接失效
            ...
          ]
      }
  ```

  



### 数据管理

* 引入[mobx](https://cn.mobx.js.org/)工具， 借助[mobx-react](https://github.com/mobxjs/mobx-react)与react结合使用

* 装饰器([Decorator](http://es6.ruanyifeng.com/#docs/decorator))文档

* mobx store创建方式

  *  /src/store文件夹下创建对应界面的store（理论上每个界面对应一个store）

  * 将上面创建的store在index.js中导出

    ```javascript
    export {overallStore} from "./overallStore";
    ```

* 修改store中的属性的方法必须使用 @action 进行修饰

  ```javascript
  @action
  test = () => {
    this.count++;
  };
  ```

  

* 异步方法在mobx中的处理方式使用 generator的方式

  ```javascript
   	// 设置选中的site
    @action
    setSelectedSite = flow(function* (site){ // 使用mobx提供的flow方法包装generator
      this.selectedSite = site;
      this.layoutLoading = true;
      try{
        let siteDetail = yield this._getSiteDetail(site.siteId);
        this.siteDetail = siteDetail.data;
      }catch (e) { // 使用try catch 捕获异步请求的异常
        Message.alert(e);
      }
      this.layoutLoading = false;
    }.bind(this)); // 使用bind this 将generator与当前类的实例进行绑定
  ```

  

### css编写

* 项目中所有的css均通过[sass](https://sass-lang.com/guide)语法进行编写



