const {override, fixBabelImports, getBabelLoader, addDecoratorsLegacy, disableEsLint} = require('customize-cra');
const {styles} = require('@ckeditor/ckeditor5-dev-utils');
const CKEditorWebpackPlugin = require( '@ckeditor/ckeditor5-dev-webpack-plugin' );

const CKEditorPlugin = new CKEditorWebpackPlugin( {
    // Main language that will be built into the main bundle.
    language: 'zh-cn',

    // Additional languages that will be emitted to the `outputDirectory`.
    // This option can be set to an array of language codes or `'all'` to build all found languages.
    // The bundle is optimized for one language when this option is omitted.
    // additionalLanguages: 'all',

    // Optional directory for emitted translations. Relative to the webpack's output.
    // Defaults to `'translations'`.
    // outputDirectory: 'ckeditor5-translations',

    // Whether the build process should fail if an error occurs.
    // Defaults to `false`.
    // strict: true,

    // Whether to log all warnings to the console.
    // Defaults to `false`.
    // verbose: true
} )

const fileLoaderMatcher = function (rule) {
    return rule.loader && rule.loader.indexOf(`file-loader`) !== -1;
};

function addPlugin(config) {
    config.module.rules[2].oneOf = [
        ...[
            /*-------------------------------------------ant design webpack config start-----------------------------------------------*/
            {
                test: /\.less$/,
                use: [
                    require.resolve('style-loader'),
                    require.resolve('css-loader'),
                    {
                        loader: require.resolve('postcss-loader'),
                        options: {
                            // Necessary for external CSS imports to work
                            // https://github.com/facebookincubator/create-react-app/issues/2677
                            ident: 'postcss',
                            plugins: () => [
                                require('postcss-flexbugs-fixes'),
                                require('postcss-preset-env')({
                                    autoprefixer: {
                                        flexbox: 'no-2009',
                                    },
                                    stage: 3,
                                }),
                            ],
                        },
                    },

                    // 此处可对ant design进行主题配置
                    {
                        loader: require.resolve('less-loader'),
                        options: {
                            javascriptEnabled: true,
                            // theme vars, also can use theme.js instead of this.
                            modifyVars: {
                                "@primary-color": "#719CF0",
                                "@menu-highlight-color": "#719CF0",
                                "@menu-item-active-bg": "rgba(13,156,240,.3)",
                                "@layout-header-background": "#1E4B9E",
                                "@layout-sider-background": "#fff",
                                "@btn-padding-sm": "0 4px - 1px"
                            },
                        },
                    },
                ]
            },
            /*-------------------------------------------ant design webpack config end-----------------------------------------------*/

            /*-------------------------------------------ckeditor5 webpack config start-----------------------------------------------*/
            {
                test: /ckeditor5-[^/\\]+[/\\]theme[/\\]icons[/\\][^/\\]+\.svg$/,
                use: ['raw-loader']
            },
            {
                test: /ckeditor5-[^/\\]+[/\\]theme[/\\].+\.css/,
                use: [
                    {
                        loader: 'style-loader',
                        options: {
                            singleton: true
                        }
                    },
                    {
                        loader: 'postcss-loader',
                        options: styles.getPostCssConfig({
                            themeImporter: {
                                themePath: require.resolve('@ckeditor/ckeditor5-theme-lark')
                            },
                            minify: true
                        })
                    }
                ]
            },
            {
                test: /\.css$/,
                exclude: /ckeditor5-[^/\\]+[/\\]theme[/\\].+\.css/,
                // (...)
            }
            /*-------------------------------------------ckeditor5 webpack config end-----------------------------------------------*/
        ],
        ...config.module.rules[2].oneOf
    ];


    // file-loader exclude
    let l = getBabelLoader(config, fileLoaderMatcher);
    let reg = /\.less$/;
    if (Array.isArray(l.exclude)) {
        l.exclude.push(reg);
    } else if (!!l.exclude) {
        l.exclude = [l.exclude, reg]
    } else {
        l.exclude = reg;
    }

    config.plugins.push(CKEditorPlugin);

    return config;
}

module.exports = override(
    addPlugin,
    fixBabelImports('import', { // 使用ant design的库
        libraryName: 'antd',
        style: true, // use less for customized theme
    }),
    addDecoratorsLegacy(), // 添加对装饰器的支持
    disableEsLint(),
);