import React, {PureComponent, Component} from 'react';
import {Input, Modal, Button, Select, Form} from "antd";
import {RESOURCE} from "../../../common/fetch";
import './changePasswordModel.scss';
import {Message} from "../../../common/message";
import { inject, observer } from 'mobx-react';

let md5 = require('md5');
let sha1 = require('js-sha1');
const FormItem = Form.Item;
const {TextArea} = Input;
const Option = Select.Option;
const formItemLayout = {
    labelCol: {span: 5},
    wrapperCol: {span: 16}
};


@inject('userStore')
@observer
class ChangePasswordModel extends Component {
    constructor(props) {
        super(props);
        this.state = {
            loading: false,
            confirmDirty: false,
            showTip: true,
            visible: false
        }
    }

    static getDerivedStateFromProps(nextProps) {
        return {
            visible: nextProps.visible
        }
    }

    handleSubmit = (form) => {
        this.setState({loading: true});
        form.validateFieldsAndScroll((err, {newPassword, oldPassword}) => {
            if (!err) {
                RESOURCE.post('/api/v1/credential/ResetPasswordByOldPassword', {newPassword:sha1(md5(newPassword)), oldPassword:sha1(md5(oldPassword))}).then(() => {
                    // history.replace('/login');
                    // Message.success('用户密码修改成功,请重新登录');
                    this.closeModel();
                    // clearStorageOfUser();
                    this.setState({loading: false});
                }).catch((e) => {
                    Message.alert(e);
                });
            }
        });
    };

    handleConfirmBlur = (e) => {
        const value = e.target.value;
        this.setState({confirmDirty: this.state.confirmDirty || !!value});
    };

    compareToFirstPassword = (rule, value, callback) => {
        const form = this.props.form;
        if (value && value !== form.getFieldValue('newPassword')) {
            callback('两次输入的密码不一致!');
        } else {
            callback();
        }
    };

    validateToNextPassword = (rule, value, callback) => {
        const form = this.props.form;
        if (value && this.state.confirmDirty) {
            form.validateFields(['confirm'], {force: true});
        }
        callback();
    };
    isRightPwd = (rule, value, callback) => {
        let myreg = /^(?![0-9]+$)(?![a-zA-Z]+$)[0-9A-Za-z]{6,16}$/;
        if (myreg.test(value)) {
            callback();
        } else {
            callback('密码长度为6到16个的英文字母、数字组合!');
        }
    };

    closeModel = () => {
        this.props.onCancel();
    };

    render() {
        let { loading } = this.state;
        let { userStore } = this.props;
        let {form}=this.props;
        const {getFieldDecorator} = this.props.form;
        return (
            <Modal
                title="修改密码"
                destroyOnClose={false}
                visible={this.state.visible}
                onOk={this.props.onOk}
                onCancel={this.props.onCancel}
                footer={null}
                centered
            >
                <div id={'privilegeForm'}>
                    <div className={'container'}>
                        <Form onSubmit={(e) => {
                            e.preventDefault();
                            return this.handleSubmit(form)
                        }}>
                            <FormItem label="账号" {...formItemLayout}>
                                <span>{userStore.user.email}</span>
                            </FormItem>
                            <FormItem label="原密码" {...formItemLayout}>
                                {getFieldDecorator('oldPassword', {
                                    rules: [{
                                        required: true, message: '请输入原始密码!',
                                    }],
                                })(
                                    <Input type="password"/>
                                )}
                            </FormItem>
                            <FormItem label="新密码" {...formItemLayout}>
                                {getFieldDecorator('newPassword', {
                                    rules: [{
                                        validator: this.isRightPwd,
                                    }, {
                                        required: true, message: '请输入新密码!',
                                    }, {
                                        validator: this.validateToNextPassword,
                                    }],
                                })(
                                    <Input type="password"/>
                                )}
                            </FormItem>
                            <FormItem label="确认新密码" {...formItemLayout}>
                                {getFieldDecorator('confirm', {
                                    rules: [{
                                        validator: this.isRightPwd,
                                    }, {
                                        required: true, message: '请确认密码!',
                                    }, {
                                        validator: this.compareToFirstPassword,
                                    }],
                                })(
                                    <Input type="password" onBlur={this.handleConfirmBlur}/>
                                )}
                            </FormItem>
                            <div className={'btnStyle'}>
                                <Button type="primary" htmlType="submit" className={'sure'}>确认</Button></div>
                        </Form>
                    </div>
                </div>
            </Modal>
        )
    }
}

export default Form.create()(ChangePasswordModel);