import React, {Component} from 'react';
import {Button, Form, Icon, Input} from "antd";
import { observer, inject } from 'mobx-react';
import './login.scss';

@inject('userStore')
@observer
class Login extends Component {
    render() {
        let { userStore } = this.props;
        return (
            <div className={'ps-login'}>
                <div className={'ps-login-content'}>
                    <WrappedLoginForm onSubmit={userStore.login} loading={userStore.loading}/>
                </div>
            </div>
        );
    }
}

class LoginForm extends React.Component {
    handleSubmit = e => {
        e.preventDefault();
        this.props.form.validateFields((err, values) => {
            if (!err) {
                this.props.onSubmit(values);
            }
        });
    };

    render() {
        const { getFieldDecorator } = this.props.form;
        return (
            <Form onSubmit={this.handleSubmit} className="login-form">
                <Form.Item>
                    {getFieldDecorator('email', {
                        rules: [{ required: true, message: '请输入用户名!' }],
                        initialValue:'1021152950@qq.com'
                    })(
                        <Input
                            prefix={<Icon type="user" style={{ color: 'rgba(0,0,0,.25)' }} />}
                            placeholder="请输入用户名"
                        />,
                    )}
                </Form.Item>
                <Form.Item>
                    {getFieldDecorator('password', {
                        rules: [{ required: true, message: '请输入密码!' }],
                        initialValue:'password123'
                    })(
                        <Input
                            prefix={<Icon type="lock" style={{ color: 'rgba(0,0,0,.25)' }} />}
                            type="password"
                            placeholder="请输入密码"
                        />,
                    )}
                </Form.Item>
                <Form.Item>
                    <Button type="primary" htmlType="submit" className="login-form-button" loading={this.props.loading}>
                        登录
                    </Button>
                </Form.Item>
            </Form>
        );
    }
}

const WrappedLoginForm = Form.create({ name: 'login' })(LoginForm);

export default Login;
