import React, {Component, Fragment} from 'react';
import './overall.scss';
import {JFLoading} from "../../component/JFLoading/JFLoading";
import {observer,inject} from "mobx-react/index";
import {JFPageHeader} from "../../component/JFPageHeader/JFPageHeader";
import {JFContent, JFContentHeader} from "../../component/JFContent/JFContent";
import {Icon, Switch} from 'antd';
import Clipboard from 'react-clipboard.js';
import {CartesianGrid, Line, LineChart, ResponsiveContainer, Tooltip, XAxis, YAxis} from "recharts";
import {Message} from "../../common/message";
import {numberSplit} from "../../common/utils";

import CKEditor from '@ckeditor/ckeditor5-react';
import ClassicEditor from '@ckeditor/ckeditor5-editor-classic/src/classiceditor';
import Alignment from '@ckeditor/ckeditor5-alignment/src/alignment';
import Heading from '@ckeditor/ckeditor5-heading/src/heading';
import Bold from '@ckeditor/ckeditor5-basic-styles/src/bold';
import Italic from '@ckeditor/ckeditor5-basic-styles/src/italic';
import Paragraph from '@ckeditor/ckeditor5-paragraph/src/paragraph';
import Link from '@ckeditor/ckeditor5-link/src/link';
import Table from '@ckeditor/ckeditor5-table/src/table';
import Essentials from '@ckeditor/ckeditor5-essentials/src/essentials';
import TableToolbar from '@ckeditor/ckeditor5-table/src/tabletoolbar';
import Font from '@ckeditor/ckeditor5-font/src/font';
import List from '@ckeditor/ckeditor5-list/src/list';
import Image from '@ckeditor/ckeditor5-image/src/image';
import ImageToolbar from '@ckeditor/ckeditor5-image/src/imagetoolbar';
import ImageCaption from '@ckeditor/ckeditor5-image/src/imagecaption';
import ImageStyle from '@ckeditor/ckeditor5-image/src/imagestyle';
import EasyImage from '@ckeditor/ckeditor5-easy-image/src/easyimage';



const ckEditorConfig = {
    plugins:[ Essentials, Heading, Font, Alignment, Bold, Italic, Link, Table, TableToolbar, List, Image, ImageToolbar, ImageCaption, ImageStyle, EasyImage ],
    toolbar: ['heading', '|', 'fontFamily', 'fontSize', 'fontColor', 'fontBackgroundColor', 'bulletedList', 'numberedList', 'alignment', 'bold','italic','link','insertTable', 'imageUpload', '|', 'undo', 'redo'],
    table: {
        contentToolbar: [ 'tableColumn', 'tableRow', 'mergeTableCells' ]
    },
    fontFamily: {
        options: [
            'default',
            'Arial, Helvetica, sans-serif',
            'Courier New, Courier, monospace',
            'Georgia, serif',
            'Lucida Sans Unicode, Lucida Grande, sans-serif',
            'Tahoma, Geneva, sans-serif',
            'Times New Roman, Times, serif',
            'Trebuchet MS, Helvetica, sans-serif',
            'Verdana, Geneva, sans-serif'
        ]
    },
    fontSize: {
        options: [12, 13, 14, 15, 'default', 17, 18, 19, 21, 22, 23, 24]
    },
    fontColor: {
        columns: 8,

        // ...
    },
    fontBackgroundColor: {
        columns: 8,

        // ...
    },
    image: {
        toolbar: [ 'imageTextAlternative', '|', 'imageStyle:full', 'imageStyle:side' ],
        styles: [
            'full',
            'side',
            'alignLeft',
            'alignCenter',
            'alignRight'
        ]
    },
    // 图片上传配置
    cloudServices: {
        // tokenUrl: 'https://example.com/cs-token-endpoint',
        // uploadUrl: 'https://your-organization-id.cke-cs.com/easyimage/upload/'
    }
};

@inject('overallStore', 'appStore')
@observer
class Overall extends Component {

    componentDidMount() {
        this.props.overallStore.init();
    }

    render() {
        let obj = {};
        let { overallStore, appStore } = this.props;
        let pvData = overallStore.pvInfo
            .filter(({ day,flows }) => { return flows.length !== 0  })
            .map(({ day,flows }) => { return { day,...(function () {
                obj = {};
                for (let i =0; i<flows.length; i++) {
                    obj['f'+i] = flows[i].count
                }
                return obj;
            }())}});
        return (
            <Fragment>
                <JFLoading loading={overallStore.loading} mask={true} />
                <div className={'ps-overall'}>
                    <JFPageHeader routes={[{ name:'总览' }]}/>
                    <JFContent>
                        <CKEditor
                            editor={ ClassicEditor }
                            data="<p>Hello from CKEditor 5!</p>"
                            config={ ckEditorConfig }
                            onInit={ editor => {
                                // You can store the "editor" and use when it is needed.
                                console.log( 'Editor is ready to use!', editor );
                            } }
                            onChange={ ( event, editor ) => {
                                const data = editor.getData();
                                console.log( { event, editor, data } );
                            } }
                            onBlur={ editor => {
                                console.log( 'Blur.', editor );
                            } }
                            onFocus={ editor => {
                                console.log( 'Focus.', editor );
                            } }
                        />
                    </JFContent>
                </div>
            </Fragment>
        );
    }
}

export default Overall;
