import { observable, action, flow, runInAction } from 'mobx';
import {RESOURCE} from "../common/fetch";
import {Message} from "../common/message";

class app {
    // 如果已经存在site 则更新页面即刻， 无site表示用户首次进入系统
    preSite = '';

    @observable siteList = [];
    @observable selectedSite = {};
    @observable layoutLoading = false;
    @observable siteDetail = {};

    // 获取site列表
    @action
    getSiteList = flow(function* () {
        this.layoutLoading = true;
        try {
            let list = yield RESOURCE.post('/api/v1/site/GetSiteAddressList');
            this.siteList = list.data;
            this.setSelectedSite(list.data[0])
        }catch (e) {
            Message.alert(e);
        }
        this.layoutLoading = false;
    }.bind(this));

    // 设置选中的site
    @action
    setSelectedSite = flow(function* (site){
        this.selectedSite = site;
        this.layoutLoading = true;
        try{
            let siteDetail = yield this._getSiteDetail(site.siteId);
            this.siteDetail = siteDetail.data;
        }catch (e) {
            Message.alert(e);
        }
        this.layoutLoading = false;
    }.bind(this));

    _getSiteDetail(siteId) {
        return RESOURCE.get('/api/v1/site/SearchSite/'+siteId);
    }

    init() {
        this.getSiteList();
    }
}

export const appStore = new app();